class AssignmentDistribution(PWReportPage):
	def init(self):
		super(AssignmentDistribution, self).init()
		self.project				= None
		self.intervalUnit			= 5
		self.iterIntervalStartDate	= None
		self.iterIntervalStartYear  = None
		self.iterIndexYear          = 0
		self.contentMode			= 0
		self.withObjective 			= True
		self.withProject            = True
		self.withMasterResources	= True
		self.withTotal				= False
		self.withWorkCost   		= False
		self.iterItem				= None
		self.iterIndex				= 0
		self.iterTitle			    = None
		self.iterTitleIndex	        = 0
		self.iterTask			    = None
		self.iterTaskIndex	        = 0
		self.masterResourcesSortDescriptors		= [NSSortDescriptor.alloc().initWithKey_ascending_("title", True)]
		return self

	def showExpectedValues(self):
		return self.contentMode == 0 

	def showDays(self):
		return self.intervalUnit == 3


		
	def masterResources(self):
		sortedMasterResources = self.project.sortedMasterResources()
		sortedMasterResources = sortedMasterResources.sortedArrayUsingDescriptors_(self.masterResourcesSortDescriptors)
		return sortedMasterResources
		
	
	def theUnit(self):
		return self.project.durationDefaults()
	


	def tasksPerResource(self):
		assignmentValues = {}
		result = NSMutableArray.array()
		result = self.iterItem.valueForKey_("assignments")
		
		byStart = NSSortDescriptor.alloc().initWithKey_ascending_("expectedStartDate", True)
		return result.sortedArrayUsingDescriptors_([byStart])

		
	
	def showObjective(self):
		return self.withObjective and self.project.itemDescription()

	def showResources(self):
		return self.withResources and len(self.resources())>0


	def rowClass(self):
		if self.iterIndex%2:
			return "even"
			
	def rowClassSubRows(self):
		if self.iterTaskIndex%2:
			return "even_var2"


	def listItemClass(self):
		if self.iterIndex == 0:
			return "first"
	
	def dateFormat(self):
		return "MMM d, YYYY"
	


	def getStart(self, parameter):
		activities = self.project.visibleSubActivitiesArray()
		startDateDescriptor = NSSortDescriptor.alloc().initWithKey_ascending_("expectedStartDate", True)
		acts = activities.sortedArrayUsingDescriptors_([startDateDescriptor])
		if acts:
			start = MEDuration.startOfUnit_containingDate_calendar_(parameter, acts[0].expectedStartDate(), self.project.sharedNSCalendar())
		else:
			start = MEDuration.startOfUnit_containingDate_calendar_(parameter, self.project.expectedStartDate(), self.project.sharedNSCalendar())
		return start

	def intervalStartDates(self):
		start = self.getStart(self.intervalUnit)
		end   = self.project.expectedEndDate()
		
		intervalStart = start
		dates = []
		
		while intervalStart<end:
			dates.append(intervalStart)
			intervalStart = MEDuration.endOfUnit_withStartDate_calendar_(self.intervalUnit, intervalStart, self.project.sharedNSCalendar())
			
		return dates


		
	def howManyDays(self):
		start = self.project.expectedStartDate()
		end = self.project.expectedEndDate()
		daysInBetween = self.project.expectedWorkingUnitsBetweenStartDate_endDate_(start, end)
		return daysInBetween
	
	def outputOrSelectAHigherInterval(self):
		if self.intervalUnit == 3:
			return self.howManyDays() < 300
		else:	
			return True
		
	def setIterIntervalStartDate_(self, date):
		self.iterIntervalStartDate = date
		self.iterIntervalEndDate = MEDuration.endOfUnit_withStartDate_calendar_(self.intervalUnit, date, self.project.sharedNSCalendar())
		
		
	def iterIntervalDescriptionMonthHeaders(self):
		start = MEDuration.startOfUnit_containingDate_calendar_(6, self.project.expectedStartDate(), self.project.sharedNSCalendar())
		end =  MEDuration.endOfUnit_withStartDate_calendar_(6, start, self.project.sharedNSCalendar())
		intervalStart = start
		dates = []
		result = []
		while intervalStart<end:
			dates.append(intervalStart)
			intervalStart = MEDuration.endOfUnit_withStartDate_calendar_(6, intervalStart, self.project.sharedNSCalendar())
			
		for date in dates:
			durationDescription = MEDuration.descriptionForUnit_style_atDate_withLocale_calendar_(6, 1, date, NSUserDefaults.standardUserDefaults().dictionaryRepresentation(), self.project.sharedNSCalendar())
			result.append(durationDescription)
	
		return result

	def iterIntervalDescription(self):
		return MEDuration.preciseDescriptionForUnit_atDate_calendar_(self.intervalUnit, self.iterIntervalStartDate, self.project.sharedNSCalendar())

	def iterIntervalCalculcationStartDate(self):
		return self.iterIntervalStartDate


	def iterIntervalExpectedWork(self):
		result = 0
		res = self.masterResources()
		if res:
			for re in res:
				a = re.expectedWorkingUnitsBetweenStartDate_endDate_(self.iterIntervalCalculcationStartDate(), self.iterIntervalEndDate)
				if a:
					result += a
		
		return "%.1f" % result



	def iterIntervalExpectedWorkPerResource(self):
		if self.iterItem != None:
			a = self.iterItem.expectedWorkingUnitsBetweenStartDate_endDate_(self.iterIntervalCalculcationStartDate(), self.iterIntervalEndDate)
			return "%.1f" % a
		else:
			return None

	def expectedWorkPerProject(self):
		result = 0
		start = self.project.expectedStartDate()
		end = self.project.expectedEndDate()
		res = self.masterResources()
		if res:
			for re in res:
				a = re.expectedWorkingUnitsBetweenStartDate_endDate_(start, end)
				if a:
					result += a
					
		return "%.1f" % result

	def actualWorkPerProject(self):
		result = 0
		start = self.project.expectedStartDate()
		end = self.project.expectedEndDate()
		res = self.masterResources()
		if res:
			for re in res:
				a = re.actualWorkingUnitsBetweenStartDate_endDate_(start, end)
				if a:
					result += a
		
		return "%.1f" % result



	def expectedWorkPerResource(self):
		start = self.project.expectedStartDate()
		end = self.project.expectedEndDate()
		if self.iterItem != None:
			a = self.iterItem.expectedWorkingUnitsBetweenStartDate_endDate_(start, end)
			return "%.1f" % a
		else:
			return None

	def actualWorkPerResource(self):
		start = self.project.expectedStartDate()
		end = self.project.expectedEndDate()
		if self.iterItem != None:
			a = self.iterItem.actualWorkingUnitsBetweenStartDate_endDate_(start, end)
			return "%.1f" % a
		else:
			return None


	def iterIntervalActualWork(self):
		result = 0
		res = self.masterResources()
		if res:
			for re in res:
				a = re.actualWorkingUnitsBetweenStartDate_endDate_(self.iterIntervalCalculcationStartDate(), self.iterIntervalEndDate)
				if a:
					result += a
		
		return "%.1f" % result


	def iterIntervalActualWorkPerResource(self):
		if self.iterItem != None:
			a = self.iterItem.actualWorkingUnitsBetweenStartDate_endDate_(self.iterIntervalCalculcationStartDate(), self.iterIntervalEndDate)
			return "%.1f" % a
		else:
			return None
		
	def expectedWorkPerAssignment(self):
		start = self.iterTask.expectedStartDate()
		end = self.iterTask.expectedEndDate()

		if self.iterTask != None:
			a = self.iterTask.expectedWorkingUnitsBetweenStartDate_endDate_(start, end)		
			return "%.1f" % a
		else:
			return None

	def actualWorkPerAssignment(self):
		start = self.iterTask.expectedStartDate()
		end = self.iterTask.expectedEndDate()

		if self.iterTask != None:
			a = self.iterTask.actualWorkingUnitsBetweenStartDate_endDate_(start, end)	
			if a != None:	
				return "%.1f" % a
		else:
			return None


	def iterIntervalExpectedWorkPerAssignment(self):
		if self.iterTask != None:
			a = self.iterTask.expectedWorkingUnitsBetweenStartDate_endDate_(self.iterIntervalCalculcationStartDate(), self.iterIntervalEndDate)		
			return "%.1f" % a
		else:
			return None
			
	def iterIntervalActualWorkPerAssignment(self):
		if self.iterTask != None:
			a = self.iterTask.actualWorkingUnitsBetweenStartDate_endDate_(self.iterIntervalCalculcationStartDate(), self.iterIntervalEndDate)
			return "%.1f" % a
		else:
			return None


